InitController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • InitController
Implemented types

Constructors

InitController()

Properties

cameraController → CameraController?
no setter
cameraService CameraService
final
getter/setter pair
debounceTimer Timer?
getter/setter pair
faceDetected bool
no setter
faceDetectorService FaceDetectorService
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
imagePath ↔ RxString
getter/setter pair
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isFaceDetected ↔ RxBool
getter/setter pair
isFlip ↔ RxBool
getter/setter pair
isInitializing ↔ RxBool
getter/setter pair
isLoaded bool
no setter
isOpen ↔ RxBool
getter/setter pair
isPictureTaken ↔ RxBool
getter/setter pair
listeners int
no setterinherited
loading ↔ RxBool
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userTextEditingController TextEditingController
final

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
detectFacesThrottled(CameraImage image) → void
dispose() → void
override
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
disposeServices() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onBackPressed() → void
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onFlipPressed() → void
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
takePicture() Future<void>
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkFacedata(File image) Future<CheckFace>
Check Face Match in Server