CheckFace class

Constructors

CheckFace({bool? status, String? msg, String? data})
CheckFace.fromJson(Map<String?, dynamic> json)
factory

Properties

data String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
msg String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String?, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited