GetData class

Constructors

GetData({String? sId, FaceData2? faceData, String? createdAt, String? updatedAt})
GetData.fromJson(Map<String, dynamic> json)

Properties

createdAt String?
getter/setter pair
faceData FaceData2?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sId String?
getter/setter pair
updatedAt String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited