description property
Implementation
static String description = "First, position your face in the camera frame. Then move your head in a circle to show all the angles of your face.";
static String description = "First, position your face in the camera frame. Then move your head in a circle to show all the angles of your face.";